PyScada GPIO Extension
======================

This is a extension for PyScada to support read and write of GPIO Pins.


What is Working
---------------

 - nothing is test


What is not Working/Missing
---------------------------

 - Test with real hardware
 - Documentation

Installation
------------

 - pip install pyscada-gpio


Contribute
----------

 - Issue Tracker: https://github.com/trombastic/PyScada-GPIO/issues
 - Source Code: https://github.com/trombastic/PyScada-GPIO
 

License
-------

The project is licensed under the _GNU General Public License v3 (GPLv3)_.
-
